==> hs-arrows-0.4.4.0_4.tbz: lib/ghc-7.4.1/cabal/arrows-0.4.4.0/register.sh <==
#!/bin/sh
echo 'name: arrows
version: 0.4.4.0
id: arrows-0.4.4.0-8e269503f40f370f62b10c9549aee345

license: BSD3
copyright:
maintainer: Ross Paterson <ross@soi.city.ac.uk>
stability:
homepage: http://www.haskell.org/arrows/
package-url:
synopsis: Arrow classes and transformers
description: Several classes that extend the Arrow class, and some
             transformers that implement or lift these classes.
category: Control
author: Ross Paterson <ross@soi.city.ac.uk>
exposed: True
exposed-modules: Control.Arrow.Operations
                 Control.Arrow.Transformer.Automaton
                 Control.Arrow.Transformer.CoState Control.Arrow.Transformer.Error
                 Control.Arrow.Transformer.State Control.Arrow.Transformer.Static
                 Control.Arrow.Transformer.Stream Control.Arrow.Transformer.Writer
                 Control.Arrow.Transformer.Reader Control.Arrow.Transformer.All
                 Control.Arrow.Transformer
hidden-modules: Control.Arrow.Internals
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.1/cabal/arrows-0.4.4.0
library-dirs: /usr/local/lib/ghc-7.4.1/cabal/arrows-0.4.4.0
              /usr/local/lib
hs-libraries: HSarrows-0.4.4.0
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: Stream-0.4.6-b51d2f67d8deb63d0b329b6b06ac4de5
         base-4.5.0.0-1a022b3476300ed3e5bfdd46dd7221d0
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.1/cabal/arrows-0.4.4.0/html/arrows.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.1/cabal/arrows-0.4.4.0/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-arrows-0.4.4.1_1.tbz: lib/ghc-7.4.2/cabal/arrows-0.4.4.1/register.sh <==
#!/bin/sh
echo 'name: arrows
version: 0.4.4.1
id: arrows-0.4.4.1-60955b03bc3f86e47481d7723254576a

license: BSD3
copyright:
maintainer: Ross Paterson <ross@soi.city.ac.uk>
stability:
homepage: http://www.haskell.org/arrows/
package-url:
synopsis: Arrow classes and transformers
description: Several classes that extend the Arrow class, and some
             transformers that implement or lift these classes.
category: Control
author: Ross Paterson <ross@soi.city.ac.uk>
exposed: True
exposed-modules: Control.Arrow.Operations
                 Control.Arrow.Transformer.Automaton
                 Control.Arrow.Transformer.CoState Control.Arrow.Transformer.Error
                 Control.Arrow.Transformer.State Control.Arrow.Transformer.Static
                 Control.Arrow.Transformer.Stream Control.Arrow.Transformer.Writer
                 Control.Arrow.Transformer.Reader Control.Arrow.Transformer.All
                 Control.Arrow.Transformer
hidden-modules: Control.Arrow.Internals
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.2/cabal/arrows-0.4.4.1
library-dirs: /usr/local/lib/ghc-7.4.2/cabal/arrows-0.4.4.1
              /usr/local/lib
hs-libraries: HSarrows-0.4.4.1
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: Stream-0.4.6.1-ebd502e2a5cbcf63c22488d39b81b736
         base-4.5.1.0-f58939ca866a8377999e7a71aa62d1d0
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.2/cabal/arrows-0.4.4.1/html/arrows.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.2/cabal/arrows-0.4.4.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
